@@ -432,9 +432,9 @@ class SendMessage(object):
         wrap_it = kwargs.get('wrap_it', None)
 
 
-        email_template = self.send_message_config.get('email_template')
+        email_body_template = self.send_message_config.get('email_body_template')
         email_subject_template = self.send_message_config.get('email_subject_template')
-        template = self.send_message_config.get('template')
+        web_front_template = self.send_message_config.get('web_front_template')
         
         toaddr = self.send_message_config.get('toaddr', '')
 
@@ -451,7 +451,7 @@ class SendMessage(object):
         replace_vars['toaddr'] = toaddr
 
         subject = self.web_newsletter.admin.email_template(email_subject_template)
-        body = self.web_newsletter.admin.email_template(email_template)
+        body = self.web_newsletter.admin.email_template(email_body_template)
         
 
         # replace the variables in the template.
@@ -466,7 +466,7 @@ class SendMessage(object):
                 self.config.get('sendmail_cmd'),
                 )
         
-        return self.web_newsletter.html_template(template, wrap_it)
+        return self.web_newsletter.html_template(web_front_template, wrap_it)
         
         
     def validate_input(self, kwargs):
@@ -475,6 +475,7 @@ class SendMessage(object):
         # see if a validation function has been used defined in the config file.
         validate_input = self.send_message_config.get('validate_input', None)
         if validate_input is not None:
+            #validate_input = eval(validate_input)
             return validate_input(kwargs)
         
         return True
@@ -498,6 +499,13 @@ class WebNewsletter(object):
 
         self.static_dir = self.config.get("static_dir")
         self.db_dir = self.config.get("db_dir")
+        self.py_dirs = self.config.get("py_dirs", None)
+
+        if self.py_dirs is not None:
+            for py_dir in self.py_dirs:
+                if py_dir not in sys.path:
+                    sys.path.append(py_dir)
+
         self.fromaddr = self.config.get("from_addr")
 
         self._default_vars = {"base_url" : self.config.get('base_url'),
@@ -987,7 +995,7 @@ def main():
 
     parser = OptionParser()
     parser.add_option("-p", "--port", dest="port",
-                      default = 9999, type = int,
+                       type = int,
                       help="port to listen on")
     parser.add_option("-m", "--mount_point", dest="mount_point",
                       default = "",
@@ -1029,10 +1037,14 @@ def main():
         
     else:
         # We run the webserver.
-        cherrypy.server.socket_port = options.port
         mount_point = options.mount_point
         cfg = options.config
 
+        py_dir = os.path.join(os.path.split(cfg)[0], "pypackages")
+        if py_dir not in sys.path:
+            sys.path.append(py_dir)
+        
+        
         # Site-wide (global) config
         log_dir = os.path.join("log")
         #if not os.path.exists(log_dir):
@@ -1071,6 +1083,14 @@ def main():
         #   have the config from cherrypy.
         wnl.load(cherrypy.tree.apps[mount_point].config)
 
+        # we use the port from the cmd line if it exists.
+        if options.port:
+            cherrypy.server.socket_port = options.port
+        else:
+            global_cfg = cherrypy.tree.apps[mount_point].config.get('global', {})
+            cfg_port = global_cfg.get('server.socket_port', 9999)
+            cherrypy.server.socket_port = cfg_port
+
         #pprint.pprint(cherrypy.tree.apps[mount_point].config)
 
         cherrypy.engine.start()
